@@ -3,23 +3,24 @@ from hashlib import md5
 
 
 def encode_password(token, password):
+    #pylint: disable=redefined-outer-name
     token = token.encode('ascii', 'strict')
     token = unhexlify(token)
     password = password.encode('ascii', 'strict')
-    md = md5()
-    md.update(b'\x00' + password + token)
-    password = hexlify(md.digest())
+    hasher = md5()
+    hasher.update(b'\x00' + password + token)
+    password = hexlify(hasher.digest())
     return '00' + password.decode('ascii', 'strict')
 
 
-def login_token(api, username, password):
+def token(api, username, password):
     """Login using pre routeros 6.43 authorization method."""
     sentence = api('/login')
-    token = sentence[0]['ret']
-    encoded = encode_password(token, password)
-    api('/login', **{'name': username, 'response': encoded})
+    tok = tuple(sentence)[0]['ret']
+    encoded = encode_password(tok, password)
+    tuple(api('/login', **{'name': username, 'response': encoded}))
 
 
-def login_plain(api, username, password):
+def plain(api, username, password):
     """Login using post routeros 6.43 authorization method."""
-    api('/login', **{'name': username, 'password': password})
+    tuple(api('/login', **{'name': username, 'password': password}))
